@@ -13,37 +13,43 @@ class EmrConfig(SparkEngineConfig):
     _conf__task_family = "emr"
 
     cluster_type = SparkClusters.emr
-    cluster = parameter.c(description="Cluster name")[str]
+    cluster = parameter.c(description="Set the cluster's name.")[str]
 
     policy = parameter.c(
-        default=ClusterPolicy.NONE, description="Cluster start/stop policy"
+        default=ClusterPolicy.NONE,
+        description="Determine the cluster's start/stop policy.",
     ).choices(ClusterPolicy.ALL)
 
     region = parameter.c(
-        description="region to use for aws connection", default="us-east-2"
+        description="Determine the region to use for the AWS connection.",
+        default="us-east-2",
     )[str]
 
     conn_id = parameter.value(
-        default="spark_emr", description="spark emr connection settings"
+        default="spark_emr", description="Set Spark emr connection settings."
     )
 
     action_on_failure = parameter.c(
-        description="Action to take on failure of spark submit CANCEL_AND_WAIT/CONTINUE",
+        description="Set an action to take on failure of Spark submit. E.g. `CANCEL_AND_WAIT` or `CONTINUE`.",
         default="CANCEL_AND_WAIT",
     )[str]
 
     emr_completion_poll_interval = parameter(
-        default=10, description="Seconds to wait between polls of step completion job"
+        default=10,
+        description="Set the numbber of seconds to wait between polls of step completion job.",
     )[int]
 
     client = parameter.c(
-        default=EmrClient.STEP, description="Type of client used to run EMR jobs"
+        default=EmrClient.STEP,
+        description="Set the type of client used to run EMR jobs.",
     )
     ssh_mode = parameter.c(
-        description="If ssh mode is on - we'll use localhost:SSH_PORT(8998) to connect to livy",
+        description="If this is enabled,  use localhost:SSH_PORT(8998) to connect to livy.",
         default=False,
     )[bool]
-    livy_port = parameter[int].c(description="Port to connect to livy", default=8998)
+    livy_port = parameter[int].c(
+        description="Set which port will be used to connect to livy.", default=8998
+    )
 
     def _validate(self):
         super(EmrConfig, self)._validate()
